summaryrefslogtreecommitdiffstats
path: root/kmail/kmheaders.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmheaders.h')
-rw-r--r--kmail/kmheaders.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmheaders.h b/kmail/kmheaders.h
index 3dce0a664..f504c3f30 100644
--- a/kmail/kmheaders.h
+++ b/kmail/kmheaders.h
@@ -10,7 +10,7 @@ using KMail::HeaderItem;
#include <klistview.h>
#include <kfoldertree.h> // for KPaintInfo
-#include <kmmsgbase.h> // for KMMsgStatus
+#include <kmmsgbase.h> // for KMMsgtqStatus
#include <tqwidget.h>
#include <tqstrlist.h>
@@ -77,13 +77,13 @@ public:
/** Set all messages in the current thread to status @p status
or toggle it, if specified. */
- virtual void setThreadStatus(KMMsgStatus status, bool toggle=false);
+ virtual void setThreadtqStatus(KMMsgtqStatus status, bool toggle=false);
/* Set message status to read if it is new, or unread */
virtual void setMsgRead(int msgId);
/** The following methods processes all selected messages. */
- virtual void setMsgStatus(KMMsgStatus status, bool toggle=false);
+ virtual void setMsgtqStatus(KMMsgtqStatus status, bool toggle=false);
virtual void deleteMsg();
virtual void applyFiltersOnMsg();
virtual void undo();
@@ -286,12 +286,12 @@ public slots:
virtual void ensureCurrentItemVisible();
/** Select an item and if it is the parent of a closed thread, also
- recursively select its children. */
+ recursively select its tqchildren. */
virtual void setSelected(TQListViewItem *item, bool selected);
/** Select several items by message index
* and if they are the parent of a closed thread, also
* recursively select their children. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
/** switch a column with the given id (see KPaintInfo enum)
@@ -299,7 +299,7 @@ public slots:
void slotToggleColumn(int id, int mode = -1);
/** Provide information about number of messages in a folder */
- void setFolderInfoStatus();
+ void setFolderInfotqStatus();
protected:
static TQPixmap *pixNew, *pixUns, *pixDel, *pixRead, *pixRep, *pixSent,
@@ -286,12 +286,12 @@ public slots:
/** Select several items by message index
* and if they are the parent of a closed thread, also
- * recursively select their children. */
+ * recursively select their tqchildren. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
/** switch a column with the given id (see KPaintInfo enum)